R parallel implementation of Local Outlier Factor(LOF) which uses multiple CPUs to significantly speed up the LOF computation for large datasets. (Note: The overall performance depends on the computers especially the number of the cores).It also supports multiple k values to be calculated in parallel, as well as various distance measures in addition to the default Euclidean distance.
| Package: | Rlof |
| Version: | 1.1.0 |
| Date: | 2015-09-10 |
| Depends: | R (>= 2.14.0), doParallel, foreach |
| License: | GPL (>= 2) |
| URL: | http://CRAN.R-project.org/package=Rlof |
| What's new: | i) a new optional parameter provided to specify the number of cores used for parallel computing |
| ii) support of Windows system |